  function lwest = berliand(yd,lat,swr,Ts,Ta,rh,cfopt,clcorr)
% BERLIAND: estimates net long-wave heat flux using Berliand approach.
% lwest = BERLIAND(yd,lat,swr,Ts,Ta,rh,cfopt,clcorr) estimates the 
% net longwave heat flux into the ocean using the Berliand and Berliand
% formula (Fung et al (1984), Rev. Geophys. Space Physics, 22,177-193).
% Program assumes that the measured input time series (yd,swr,Ts,Ta,rh)
% are hourly and are either all column (m,1) or all row (1,m) vectors. 
% If not measured, a scalar value of rh may be entered. Output vector has
% same shape as input vectors.
%
%   INPUTS: yd - yearday (e.g., 0000Z Jan 1 is 0.0)
%           lat - latitude (decimal deg)
%           swr - measured insolation (W/m^2)
%           Ts - sea surface temperature (deg C)
%           Ta - air temperature (deg C)
%           rh - relative humidity (%)
%           cfopt - cloud factor option [Krauss=0 or Reed=1] 
%           clcorr - cloud correction factor [linear=0 with (1 - 0.75*cf) 
%                    or quadratic=1 with (1 - 0.67*cf^2)]
%
%   OUTPUT: lwest - net upward longwave flux (W/m^2)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 3/12/96: version 1.0
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% determine shape of input vectors
[m,n] = size(swr);

% estimate daily averaged cloud factor
if cfopt == 1
  cf= reedcf(yd,lat,swr);
elseif cfopt == 0
  cf = krausscf(yd,swr);
end

% cloudfac always outputs a column vector, so if initial 
% input is row vector, convert cf to row vector
if m==1
  cf  = cf';
end

% set constants
eps = 0.98;
sigma = 5.67e-8;
Ts = Ts + 273.16;
Ta = Ta + 273.16;
humid = 640380*exp(-5107.4./(Ta));
e = rh./100.*humid.*461.5.*(Ta)/100;
if clcorr == 0
  b = 0.75;
  Fc = 1 - b*cf;
elseif clcorr == 1
  b = 0.67;
  Fc = 1 - b*cf.^2;
end
lw1 = eps*sigma.*Ta.^4.*(0.39 - 0.05*sqrt(e)).*Fc;
lw2 = 4*eps*sigma.*Ta.^3.*(Ts - Ta);
lwest = lw1 + lw2;
% for heat flux into coean
lwest=-lwest;
end
