  function sradav = clskswr(yd,lat)
% CLSKSWR: computes clear sky insolation following Seckel&Beaudry (1973).
% sradav = CLSKSWR(yd,lat) computes average clear sky solar insolation
% based on the Seckel and Beaudry (1973) formula (also called the 
% Smithsonian formula) presented in Reed (1977), J. Phys. Ocean., 7, 
% 482-485. Assumes lat is a fixed scalar and the year is not a leap year.
% If yd is negative, then yd=yd+365.
%
%   INPUT:  yd  -  yearday (e.g., Jan 10th is 10) 
%           lat -  latitude (decimal deg)
%  
%   OUTPUT: sradav - clear sky mean daily insolation (W/m^2)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 3/8/97: version 1.0
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

radlat = pi*lat/180;

[N,M]=size(yd);
if N==1
   yd=yd';
end

% check if yd is negative
ind=find(yd<0);
yd(ind)=yd(ind)+365;
% truncate to integer yearday for use with formula
yd=fix(yd);

phi = (yd-21)*360/365;
phi = pi*phi/180;
if abs(lat) <= 40
  a0 = -15.82 + 326.87*cos(radlat);
  a1 = 9.63 + 192.44*cos(radlat+pi/2);
  b1 = -3.27 + 108.70*sin(radlat);
  a2 = -0.64 + 7.80*sin(2*(radlat-pi/4));
  b2 = -0.50 + 14.42*cos(2*(radlat-5*pi/180));
  sradav = a0 + a1*cos(phi) + b1*sin(phi) + a2*cos(2*phi) + b2*sin(2*phi);
end
if abs(lat) > 40 & abs(lat) <= 60
  a0 = 342.61 - 1.97*lat - 0.018*lat^2;
  a1 = 52.08 - 5.86*lat + 0.043*lat^2;
  b1 = -4.80 + 2.46*lat -0.017*lat^2;
  a2 = 1.08 - 0.47*lat + 0.011*lat^2;
  b2 = -38.79 + 2.43*lat - 0.034*lat^2;
  sradav = a0 + a1*cos(phi) + b1*sin(phi) + a2*cos(2*phi) + b2*sin(2*phi);
end
if abs(lat) > 60
  disp('Formula only works for latitude less than 60 deg N')
  break
end

if N==1
  sradav=sradav';
end

end

