  function A=hfbulktc(ur,zr,Ta,zt,rh,zq,Pa,Ts)
% HFBULKTC: computes sensible and latent heat fluxes and other variables.
% A=HFBULKTC(ur,zr,Ta,zt,rh,zq,Pa,Ts) computes the following variables:
%
%           Hs = sensible heat flux into ocean (W/m^2)
%           Hl = latent heat flux into ocean (W/m^2)
%           stress = wind stress (N/m^2)
%           usb = velocity friction scale (m/s)
%           Tsb = temperature scale (deg C)
%           Qsb = humidity scale (kg/kg)
%           L = Monin-Obukoff length (m)
%           zetu = zr/L
%           CD = drag coefficient
%           CT = temperature transfer coefficient (Stanton number)
%           CQ = moisture transfer coefficient (Dalton number)
%           RI = bulk Richardson number
%
% Based on the following buoy input data:
%
%           ur = wind speed (m/s) measured at height zr (m)
%           Ta = air temperature (deg C) measured at height zt (m)
%           rh = relative humidity (%) measured at height zq (m)
%           Pa = air pressure (mb)
%           Ts = sea surface temperature (deg C)
%
% where ur, Ta, rh, Pa, and Ts may be either row or column vectors; zr,
% zt, and zq fixed scalars. rh and Pa may also be fixed scalars. Output
% variables are given as column vectors in A, i.e.,
%
%           A=[Hs Hl stress usb Tsb L zetu RI CD CT CQ]
%
% Code follows Edson and Fairall TOGA COARE code (version 2.0), modified 
% to include Rogers' weighting factor for unstable conditions.  Code does
% include gustiness (with a minimum wind gust speed of 0.5 m/s under 
% stable conditions), and assumes that the marine boundary layer height is
% known and constant over time for simiplicity (Zi = 650 m unless
% otherwise set).  zr/L is limited to be <=1.0 to ensure that the code 
% converges to nonzero stress and heat flux values for strongly stable 
% conditions.  The bulk Richardson number is computed between the sea 
% surface and zr as a diagnostic about whether turbulent boundary layer
% theory is applicable.  Code does not include either warm layer or cool
% skin effects to modify Ts.  See Fairall et al (1996), J. Geophys. Res.,
% 101, 3747-3764, for description of full TOGA COARE code and comparsion
% with data.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 3/8/97: Version 1.0
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% change column vectors to row vectors if necessary
[m n] = size(ur);
if m > n
  ur = ur';
end
[m n] = size(Ta);
if m > n
  Ta = Ta';
end
[m n] = size(rh);
if m > n
  rh = rh';
end
[m n] = size(Ts);
if m > n
  Ts = Ts';
end
[m n] = size(Pa);
if m > n
  Pa = Pa';
end

% initialize output and other variables
M=length(ur);
Hs=zeros(1,M);
Hl=zeros(1,M);
usb=zeros(1,M);
Tsb=zeros(1,M);
Qsb=zeros(1,M);
stress=zeros(1,M);
L=zeros(1,M);
zetu=zeros(1,M);
zett=zeros(1,M);
zetq=zeros(1,M);
Tvsb=zeros(1,M);
Tv=zeros(1,M);
rho=zeros(1,M);
Zi=650.*ones(1,M);
RI=zeros(1,M);

% create vectors for rh and Pa if scalars are input
if length(rh)==1 & M>1
  rh=rh.*ones(1,M);
end
if length(Pa)==1 & M>1
  Pa=Pa.*ones(1,M);
end

% set constants
k=.4; % von Karman's constant (code assumes kt=kq=k)
g=9.8;
cp=1004.7;
onethird=1./3;
% compute Le and air viscosity
Le=(2.501-0.00237.*Ts).*10^6;
visc=viscair(Ta);

% compute specific humidity and other variables
Qsats=0.98.*qsat(Ts);
Qa=(0.01.*rh).*qsat(Ta);
Tab=Ta+273.16;
Tv=Tab.*(1+0.61.*Qa);
rho=(100.*Pa)./(287.*Tv);

% compute vertical differences
Du=ur;
% to prevent division by zero
in=find(Du==0);
  if in~=[];
    Du(in)=0.1.*ones(1,length(in));
  end
wg=0.5.*ones(1,M); % initial guess of wind gustiness
Dug=sqrt(Du.^2 + wg.^2);
Dt=(Ta+0.0098.*zt)-Ts;
Dq=Qa-Qsats;

% compute bulk Richardson number
RI=g.*zr.*(Dt+0.61.*Tab.*Dq)./(Tab.*Dug.^2);

% compute initial neutral scaling coefficients
z0t=7.5*10^(-5);
z0q=z0t;
cdn=cdntc(Dug,zr,Ta); % Smith's neutral cd
cdnhf=sqrt(cdn);
ctnhf=k./log(zt./z0t);
cqnhf=k./log(zq./z0q);
usb=cdnhf.*Dug;
Tsb=ctnhf.*Dt;
Qsb=cqnhf.*Dq;
Tvsb=Tsb.*(1+0.61.*Qa)+0.61.*Tab.*Qsb;

% begin iteration loop to compute best usb, Tsb, and Qsb
for iter1=1:20;
z0=(.011./g).*usb.^2 + .11.*visc./usb;

% compute zr/L (assumes usb>0), zt/L, and zq/L
zetu=zr.*(k.*g.*Tvsb)./(Tv.*usb.^2);
% set upper limit on zr/L = 1.0 to force convergence under 
% very stable conditions. Assume that zr, zt and zq compariable.
in=find(zetu>1.0);
 if in~=[];
   zetu(in)=1.0.* ones(1,length(in));
 end
zett=zt.*zetu./zr;
zetq=zq.*zetu./zr;

% compute new usb and Reu
Psiu=psiutc(zetu);
usb=k.*Dug./(log(zr./z0)-Psiu);
Reu=z0.*usb./visc;

% compute t and q Reynolds numbers
   Ret=.177*ones(1,M);
   Req=.292*ones(1,M);
j=find(Reu>.11 & Reu<=.825);
   Ret(j)=1.376.*Reu(j).^0.929;
   Req(j)=1.808.*Reu(j).^0.826;
j=find(Reu>.825 & Reu<=3);
   Ret(j)=1.026./Reu(j).^0.599;
   Req(j)=1.393./Reu(j).^0.528;
j=find(Reu>3 & Reu<=10);
   Ret(j)=1.625./Reu(j).^1.018;
   Req(j)=1.956./Reu(j).^0.870;
j=find(Reu>10 & Reu<=30);
   Ret(j)=4.661./Reu(j).^1.475;
   Req(j)=4.994./Reu(j).^1.297;
j=find(Reu>30);
   Ret(j)=34.904./Reu(j).^2.067;
   Req(j)=30.790./Reu(j).^1.845;

% compute t and q roughness scales
z0t=visc.*Ret./usb;
z0q=visc.*Req./usb;

% compute profile stability functions (Roger's version)
Psit=psittc(zett);
Psiq=psittc(zetq);

% compute new transfer coefficients at measurement heights
cthf=k./(log(zt./z0t)-Psit);
cqhf=k./(log(zq./z0q)-Psiq);

% compute new values of Ts, Qs, and Tvsb
Tsb=cthf.*Dt;
Qsb=cqhf.*Dq;
Tvsb=Tsb.*(1+0.61.*Qa)+0.61.*Tab.*Qsb;

% estimate new gustiness
Bf=-g.*usb.*Tvsb./Tab;
wg=0.5.*ones(1,M); % assumed minimum value under all conditions
j=find(zetu<0);
wg(j)=1.2.*(Bf(j).*Zi(j)).^onethird;
Dug=sqrt(Du.^2 + wg.^2);

end % end of iteration loop

% compute output variables
stress=rho.*usb.^2;
% compute fluxes into ocean
Hs=rho.*cp.*usb.*Tsb;
Hl=rho.*Le.*usb.*Qsb;
L=zr./zetu;
% compute transfer coefficients at measurement heights
CD=(usb./Du).^2;
CT=usb.*Tsb./(Du.*Dt); % Stanton number
CQ=usb.*Qsb./(Du.*Dq); % Dalton number

A=[Hs' Hl' stress' usb' Tsb' L' zetu' RI' CD' CT' CQ'];
end


