  function tau=stresstc(sp,z,Ta)
% STRESSTC: computes the neutral wind stress following Smith (1988).
% tau = STRESSTC(sp,z,Ta) computes the neutral wind stress given the 
% wind speed and air temperature at height z following Smith (1988),
% J. Geophys. Res., 93, 311-326. Assumes z a fixed scalar and a 
% constant air density (1.22 kg/m^3).
%
%   INPUT:  sp - wind speed (m/s)
%           z  - measurement height (m)
%           Ta - air temperature (deg C)
%
%   OUTPUT: tau - wind stress (N/m^2)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 3/8/97: version 1.0
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% compute constants
k=.4;
g=9.8;
rho= 1.22;

[N,M]=size(sp);
if N==1
   sp=sp';
   Ta=Ta';
end

visc=viscair(Ta);

% remove any sp==0 to prevent division by zero
i=find(sp==0);
sp(i)=.1.*ones(length(i),1);

% initial guess
ustar=.036.*sp;

% iterate to find z0 and ustar
for j=1:10;
z0=.011.*ustar.^2./g +.11*visc./ustar;
ustar=sp.*(k./log(z./z0));
end

% compute stress
tau=rho*ustar.^2;
if N==1
   tau=tau';
end
end

